import React, { useState, useEffect } from 'react'
import { Input, Modal, Dropdown, Menu } from 'antd'
import styles from './index.less'
import Drag from '../../../../components/Drag'
import { LoadTableFields, ReloadTableFields } from '../../../../../apis/process';
const fnList = [
  { label: '本人姓名', value: '$本人姓名' },
  { label: '本人ID', value: '$本人ID' },
  { label: '本人部门', value: '$本人部门' },
  { label: '本人部门ID', value: '$本人部门ID' },
  { label: '本表单工单编号', value: '$本表单工单编号' },
]

const SqlFilter = (props) => {

  const { value, onChange, addons } = props
  const { tableNameParent, widget, $id } = addons.formData;
  const [visible, setVisible] = useState(false)
  const [inputValue, setInputValue] = useState('')
  const [fields, setFields] = useState([]);

  useEffect(() => {
    getFieldData();
  }, []);
  const onFocus = () => {
    setInputValue(value || '')
    setVisible(true)
  }

  const insertFn = text => {
    let ednIndex = document.getElementById('SqlFilter').selectionEnd
    let rangeIndex = document.getElementById('SqlFilter').selectionStart
    setInputValue(`${inputValue.slice(0, rangeIndex)}${text}${inputValue.slice(rangeIndex)}`)
    rangeIndex += text.toString().length
    ruleText.current.focus()
  }

    const getFieldData = async () => {
  
      if (!tableNameParent) {
          return message.info('缺少表名!')
        }
      const { data } = await ReloadTableFields({ tableName: tableNameParent });
      if (Array.isArray(data.root)) {
          const fields = data.root.map(x=> {
            return { value: `{${x.name}}`, label: x.name }
          });
          setFields(fields);
        }
      console.log(data, 'data');
    };

  const onOk = () => {
    onChange(inputValue)
    setVisible(false)
  }

  const fnListRender = (
    <Menu>
      {fnList.map(item => (
        <Menu.Item key={item.value} onClick={() => insertFn(item.value)}>
          {item.label}
        </Menu.Item>
      ))}
    </Menu>
  )

  return (
    <div className={styles.sqlFilter}>
      <Input.TextArea
        value={value}
        onClick={onFocus}
        style={{ width: '100%' }}
        rows={4}
        placeholder='示例：部门="XX部门"'
      />
      <Drag
        onCancel={() => setVisible(false)}
        onOk={onOk}
        title={'SQL过滤'}
        visible={visible}
        width={800}
        bodyStyle={{
          height: 350,
        }}
      >
        <div style={{
          width: '100%',
          height: '100%',
          display: 'flex',
        }}>
          <div className={styles.fieldListBox}>
            <div style={{
              fontSize: 14,
              fontWeight: 'bold',
              marginBottom: 5,
              paddingRight: 10
            }}>{tableNameParent}</div>
            <div className={styles.fieldList}>
              {fields.map((item, index) => (
                <div key={index} onClick={()=> insertFn(item.value)}>{item.label}</div>))}
            </div>
           
          </div>
          <div className={styles.textAreaBox}>
            <Input.TextArea
              id="SqlFilter"
              value={inputValue}
              onChange={(e) => setInputValue(e.target.value)}
              rows={4}
              placeholder='示例：部门="XX部门"'
            />
            <Dropdown overlay={fnListRender} placement="bottom" arrow>
              <div className={styles.insertFn}>自定义变量</div>
            </Dropdown>
          </div>
        </div>
       
      </Drag>
    </div>
  )

}

export default SqlFilter